==> mono_1.9.1+dfsg.orig.tar.gz: mono-1.9.1+dfsg/mcs/class/System.Web/System.Web/HttpCacheVaryByContentEncodings.cs <==
//
// System.Web.HttpCacheVaryByContentEncodings
//
// Authors:
//   Marek Habersack (mhabersack@novell.com)
//
// (C) 2007 Novell, Inc
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
#if NET_2_0
using System;
using System.Collections.Generic;
using System.Security.Permissions;

namespace System.Web 
{
	[AspNetHostingPermissionAttribute(SecurityAction.LinkDemand, Level = AspNetHostingPermissionLevel.Minimal)]
	public sealed class HttpCacheVaryByContentEncodings
	{
		Dictionary <string, bool> encodings;

		internal HttpCacheVaryByContentEncodings ()
		{
			encodings = new Dictionary <string, bool> ();
		}
		
		public bool this [string contentEncoding] {
			get {
				if (contentEncoding == null)
					throw new ArgumentNullException ("contentEncoding");

				if (encodings.ContainsKey (contentEncoding))
					return encodings [contentEncoding];

				return false;
			}
			
			set {
				if (contentEncoding == null)
					throw new ArgumentNullException ("contentEncoding");

				encodings [contentEncoding] = value;
			}
		}
	}
}
#endif

==> mono_3.2.8+dfsg.orig.tar.gz: mono-3.2.8+dfsg/mcs/class/System.Web/System.Web/HttpCacheVaryByContentEncodings.cs <==
//
// System.Web.HttpCacheVaryByContentEncodings
//
// Authors:
//   Marek Habersack (mhabersack@novell.com)
//
// (C) 2007-2009 Novell, Inc (http://novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.Collections.Generic;
using System.Security.Permissions;

namespace System.Web 
{
	[AspNetHostingPermissionAttribute(SecurityAction.LinkDemand, Level = AspNetHostingPermissionLevel.Minimal)]
	public sealed class HttpCacheVaryByContentEncodings
	{
		Dictionary <string, bool> encodings;

#if NET_4_0
		public
#else
		internal
#endif
		HttpCacheVaryByContentEncodings ()
		{
			encodings = new Dictionary <string, bool> ();
		}
		
		public bool this [string contentEncoding] {
			get {
				if (contentEncoding == null)
					throw new ArgumentNullException ("contentEncoding");

				if (encodings.ContainsKey (contentEncoding))
					return encodings [contentEncoding];

				return false;
			}
			
			set {
				if (contentEncoding == null)
					throw new ArgumentNullException ("contentEncoding");

				encodings [contentEncoding] = value;
			}
		}
	}
}
